Package: diffwrap
Type: Package
Title: Differential Expression Analysis of RNA-Seq Data
Version: 0.6-3
Date: 2026-08-10
Authors@R: person(list("Vidal", "Meeri", "Reija", "Bogdan", "Adrien"), list("Fey", "Pekkarinen", "Hieta", "Iancu", "Janssens"), email = list("vidal.fey@gmail.com", "meeri.pekkarinen@gmail.com", "reija.hieta@geneviatechnologies.com", "bogdan.iancu@abo.fi", "Adrien.RFM.Janssens@proton.me"), role = list(c("aut", "cre"), "aut", "aut", "aut", "aut"))
Description: Functions for differential expression analysis of read counts from
    messenger RNA (mRNA) sequencing (RNA-Seq) data or micro RNA (miRNA) expression
    values generated by the Comprehensive Analysis Pipeline for microRNA Sequencing
    (CAP-miRSeq) 'expression_reports.sh' script. The workflow follows the
    'edgeR'-'limma' expression data analysis pipeline providing options for different
    approaches, such as "pure" 'edgeR', voom or paired samples. The functions in the
    package generate text files with differential expression lists, optionally
    annotated with information from 'biomart', expression summary plots as well as
    several quality control (QC) plots. The main function, diffExpr(), is a
    convenience wrapper performing all steps automatically based on sensible defaults.
    Methods are described in Robinson, McCarthy and Smyth (2010)
    <doi:10.1093/bioinformatics/btp616>, Ritchie et al. (2015)
    <doi:10.1093/nar/gkv007>, Law et al. (2014) <doi:10.1186/gb-2014-15-2-r29> and
    Sun et al. (2014) <doi:10.1186/1471-2164-15-423>.
Maintainer: Vidal Fey <vidal.fey@gmail.com>
Depends: R (>= 4.0.0)
Imports: plyr, ggplot2, edgeR, limma, RColorBrewer, convertid (>=
        0.3.4), pheatmap, ggrepel, data.table, magrittr, methods,
        Hmisc, ltm, openxlsx, purrr, dplyr, venn, VennDiagram, grid,
        scales
Suggests: testthat (>= 3.0.0), withr, futile.logger, rappdirs, knitr,
        quarto, dendextend, rmarkdown, AnnotationDbi, org.Hs.eg.db,
        org.Mm.eg.db, clusterProfiler, gprofiler2, topGO, igraph,
        scatterplot3d, readxl, WriteXLS, biomaRt
License: GPL-3
Encoding: UTF-8
LazyData: true
VignetteBuilder: quarto
NeedsCompilation: no
Author: Vidal Fey [aut, cre],
  Meeri Pekkarinen [aut],
  Reija Hieta [aut],
  Bogdan Iancu [aut],
  Adrien Janssens [aut]
Config/roxygen2/version: 8.0.0
Packaged: 2026-08-10 12:45:35 UTC; fsvife
Repository: CRAN
Date/Publication: 2026-08-30 09:10:19 UTC
