% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/venn_functions.R
\name{diffr_venn}
\alias{diffr_venn}
\title{Function to produce a Venn diagram of differentially expressed gene tables}
\usage{
diffr_venn(list.comp.tables, join.vec = "gene_symbol", .log = FALSE)
}
\arguments{
\item{list.comp.tables}{list of DE tables, preferably a list of data.frames}

\item{join.vec}{vector to perform the join operation on; corresponds to column names in the DE tables.
Defaults to \code{"gene_symbol"}, the column present in every diffwrap DE table. A longer vector
(e.g. also including \code{"ensembl_gene_id"}) joins on more annotation columns, but note that every
column named here must exist in each input table.}

\item{.log}{Logical; should logging be done?}
}
\value{
A list containing the Venn diagram grid object and the intersected (or joined) input tables.
}
\description{
Function to produce a Venn diagram of differentially expressed gene tables
}
\details{
The actual plot is produced in the main plotting function by means of 'grid::grid.draw()' using the plot object as input.
}
\examples{
\donttest{
mk <- function(sig) data.frame(gene_symbol = paste0("G", sig), fdr = 0.01)
tabs <- list(A = mk(1:20), B = mk(10:30))
v <- diffr_venn(tabs, join.vec = "gene_symbol")
names(v)
}
}
\author{
Bogdan Iancu - Genevia Technologies Oy
}
