% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{quantile_breaks}
\alias{quantile_breaks}
\title{Function to define quantile breaks to be used for changing the palette of the heatmap.}
\usage{
quantile_breaks(xs, n = 20)
}
\arguments{
\item{xs}{numeric vector to calculate quantiles for}

\item{n}{desired length of the numeric vector of probabilities (see ?quantile)}
}
\value{
A \code{numeric} vector of unique quantile break points, of length at most \option{n}.
}
\description{
Function to define quantile breaks to be used for changing the palette of the heatmap.
}
\note{
Function by: Kamil Slowikowski, https://github.com/slowkow/slowkow.com/blob/master/_rmd/2017-02-16-heatmap-tutorial.R,
}
\seealso{
[quantile()]
}
