% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unexported.R
\name{fmt_dur}
\alias{fmt_dur}
\title{Convert a numeric value of seconds to human-readable duration}
\usage{
fmt_dur(secs)
}
\arguments{
\item{secs}{(\code{numeric}). run time in seconds}
}
\value{
Character string with run time information.
}
\description{
Convert a numeric value of seconds to human-readable duration
}
\keyword{internal}
