% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diffwrap-package.R
\docType{package}
\name{diffwrap-package}
\alias{diffwrap-package}
\title{diffwrap: Differential Expression Analysis of RNA-Seq Data}
\description{
Functions for differential expression analysis of read counts from messenger RNA (mRNA) sequencing (RNA-Seq) data or micro RNA (miRNA) expression values generated by the Comprehensive Analysis Pipeline for microRNA Sequencing (CAP-miRSeq) 'expression_reports.sh' script. The workflow follows the 'edgeR'-'limma' expression data analysis pipeline providing options for different approaches, such as "pure" 'edgeR', voom or paired samples. The functions in the package generate text files with differential expression lists, optionally annotated with information from 'biomart', expression summary plots as well as several quality control (QC) plots. The main function, diffExpr(), is a convenience wrapper performing all steps automatically based on sensible defaults. Methods are described in Robinson, McCarthy and Smyth (2010) \doi{10.1093/bioinformatics/btp616}, Ritchie et al. (2015) \doi{10.1093/nar/gkv007}, Law et al. (2014) \doi{10.1186/gb-2014-15-2-r29} and Sun et al. (2014) \doi{10.1186/1471-2164-15-423}.
}
\author{
\strong{Maintainer}: Vidal Fey \email{vidal.fey@gmail.com}

Authors:
\itemize{
  \item Vidal Fey \email{vidal.fey@gmail.com}
  \item Meeri Pekkarinen \email{meeri.pekkarinen@gmail.com}
  \item Reija Hieta \email{reija.hieta@geneviatechnologies.com}
  \item Bogdan Iancu \email{bogdan.iancu@abo.fi}
  \item Adrien Janssens \email{Adrien.RFM.Janssens@proton.me}
}

}
\keyword{internal}
