% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{make_pheatmap_anno_color}
\alias{make_pheatmap_anno_color}
\title{Function to create the annotation colour list used in the heatmap}
\usage{
make_pheatmap_anno_color(clinical.mat)
}
\arguments{
\item{clinical.mat}{matrix with clinical annotation values in (clinical category, samples) format}
}
\value{
A named \code{list} of named character vectors of colours, one element per annotation
  variable, in the form expected by the \code{annotation_colors} argument of
  \code{\link[pheatmap]{pheatmap}}.
}
\description{
Function to create the annotation colour list used in the heatmap
}
