% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/counts_read_and_filter.R
\name{diff_expr_read_counts}
\alias{diff_expr_read_counts}
\title{Function to read counts as produced by htseq-count}
\usage{
diff_expr_read_counts(expr.dat, samp.info, miRSEQ = FALSE)
}
\arguments{
\item{expr.dat}{\code{character} or \code{list}. String or vector or list of input file paths, or matrix of count values.
Allowed are individual text files with counts for one sample each, with gene IDs in the first and counts in the second column or
a single counts matrix file containing read counts for all samples with rows corresponding to genes (genomic features) and columns to samples.
Negative values or NAs are not allowed and gene IDs are expected in the first column.
If \code{miRSEQ=TRUE} this expects the output from CAP-miRSEQ summary script which is also a counts matrix.}

\item{samp.info}{\code{data.frame}. samp.info object containing information of the project's sample sheet.}

\item{miRSEQ}{\code{logical}. Is the input data the output from CAP-miRSEQ summary script?}
}
\value{
A \code{matrix} of raw counts with features in rows and samples in columns, restricted to the
  samples listed in \option{samp.info} and ordered as they are there.
}
\description{
Function to read counts as produced by htseq-count
}
\examples{
si <- diff_expr_get_samp_info(diffwrap_samp_info, "SampleName", "Group")
counts <- diff_expr_read_counts(diffwrap_counts, si)
dim(counts)
}
