% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{get_hm_colors}
\alias{get_hm_colors}
\title{Function to compute colour palettes to be used in the heatmap.}
\usage{
get_hm_colors(
  palette.length = 100,
  color.extremes = c("#3182BD", "#E6550D"),
  breaks = NA,
  color.blind.pal = NULL,
  n.pal.cols = 11
)
}
\arguments{
\item{palette.length}{integer setting the desired length of the colour palette to be used in the heatmap}

\item{color.extremes}{character vector of length 2 giving the two extremes of a user-defined colour palette
varying from the first hue to the second via white.}

\item{breaks}{numeric vector of breaks to be used for compute the colour palette;
defaults to NA which means no breaks are used and later computed by 'pheatmap()'.}

\item{color.blind.pal}{string determining the RColorBrewer color blind palette (default = "PuOr");
other option can be visualized with the following command: 'brewer.pal.info[brewer.pal.info$colorblind,]'}

\item{n.pal.cols}{integer giving the number of different colours in 'color.blind.pal'.}
}
\value{
a character vector containing the colour codes to be used in the heatmap.
}
\description{
Function to compute colour palettes to be used in the heatmap.
}
\seealso{
[colorRampPalette()]
}
