% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enrichment_util.R
\name{prepare_scale_for_legend}
\alias{prepare_scale_for_legend}
\title{Helper function for enrichment visualisations: prepare plot legend y coordinates and labels}
\usage{
prepare_scale_for_legend(
  scale.minimum,
  scale.maximum,
  int.values.for.ticks = NULL
)
}
\arguments{
\item{scale.minimum}{Numeric; minimum y coordinates for text labels}

\item{scale.maximum}{Numeric; maximum y coordinates for text labels}

\item{int.values.for.ticks}{Not implemented.}
}
\value{
A named \code{list} with the elements \code{scale.y.coordinates} (the vertical positions of
  the legend tick labels) and \code{scale.labels} (the corresponding label values).
}
\description{
Helper function for enrichment visualisations: prepare plot legend y coordinates and labels
}
\details{
The coordinates are used in a network graph and minimum and maximum scale values correspond to
  minimum and maximum fold-changes, by default.
}
\examples{
prepare_scale_for_legend(scale.minimum = -3, scale.maximum = 4)
}
