% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{reorderFactors}
\alias{reorderFactors}
\title{Function which reorders the levels of a column of a data frame specified as a factor}
\usage{
reorderFactors(df, column = "my_column_name", desired_level_order)
}
\arguments{
\item{df}{data frame to be processed}

\item{column}{name of the column to be reordered}

\item{desired_level_order}{vector of factor levels in the desired order}
}
\value{
The input \code{data.frame} with the levels of the specified factor column reordered.
}
\description{
Function which reorders the levels of a column of a data frame specified as a factor
}
\details{
The desired order is a vector containing the levels of the factor in the desired order.
}
\note{
Written by https://stackoverflow.com/users/1701600/boern.
}
