% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{get_hm_breaks}
\alias{get_hm_breaks}
\title{Function to define breaks to be used for changing the palette of the heatmap.}
\usage{
get_hm_breaks(
  expr.mat,
  scale.fl = "row",
  palette.length = 100,
  quantile.breaks.fl = FALSE,
  n = 11
)
}
\arguments{
\item{expr.mat}{differential gene expression matrix or data frame in (genes, samples) format}

\item{scale.fl}{character indicating if values should be centred and scaled in either
the row direction or the column direction, or none (values %in%
("row","column","none"), default = none)}

\item{palette.length}{integer setting the desired length of the colour palette to be used in the heatmap}

\item{quantile.breaks.fl}{boolean values determining if quantile breaks are used to change
the colors of the heatmap, otherwise min-max breaks are used by default}

\item{n}{desired length of the numeric vector of probabilities (see ?quantile); defaults to
the number of different colours in the palette}
}
\value{
a numeric vector containing the breaks to be used in the heatmap (see 'breaks' in [pheatmap()]).
}
\description{
Function to define breaks to be used for changing the palette of the heatmap.
}
\seealso{
[quantile()]
}
