% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qc_plots.R
\name{diff_expr_dendro_plot}
\alias{diff_expr_dendro_plot}
\title{Function to generate dendrogram plots based on hierarchical clustering}
\usage{
diff_expr_dendro_plot(
  counts,
  groups,
  grp.nam = NULL,
  main = NULL,
  col.grps = FALSE
)
}
\arguments{
\item{counts}{Counts matrix.}

\item{groups}{Sample groups for plot annotation as character vector or factor.}

\item{grp.nam}{Legend title.}

\item{main}{Plot title.}

\item{col.grps}{Logical indicating whether to colour the dendrogram by groups.}
}
\value{
No return value. Called for its side effect of drawing a hierarchical clustering dendrogram on
  the current graphics device.
}
\description{
Function to generate dendrogram plots based on hierarchical clustering
}
\examples{
\donttest{
si <- diff_expr_get_samp_info(diffwrap_samp_info, "SampleName", "Group")
counts <- diff_expr_filter_counts(diff_expr_read_counts(diffwrap_counts, si), si)
groups <- stats::relevel(si$Groups, ref = "control")
diff_expr_dendro_plot(edgeR::cpm(counts, log = TRUE), groups = groups)
}
}
