% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmapfunction.R
\name{correlogram_pheatmap}
\alias{correlogram_pheatmap}
\title{Function to create a correlogram pheatmap, i.e., a plot to check randomness in the data set.}
\usage{
correlogram_pheatmap(
  expr.mat,
  clinical.mat,
  scale.fl = "none",
  legend.fl = TRUE,
  row.clust = TRUE,
  col.clust = TRUE,
  signif.stars.fl = FALSE,
  cell.size = 8,
  font.size = 11,
  color.blind.pal = "PuOr",
  color.extremes = c("#3182BD", "#E6550D"),
  anno.color = NULL,
  main.correl = "Correlogram",
  sample.correl = FALSE
)
}
\arguments{
\item{expr.mat}{differential expression matrix in  (genes, samples) format}

\item{clinical.mat}{matrix with clinical annotation values in (clinical category, samples) format}

\item{scale.fl}{character indicating if values should be centred and scaled in either
the row direction or the column direction, or none (values %in%
("row","column","none"), default = none)}

\item{legend.fl}{logical to determine if legend should be drawn or not (default = TRUE)}

\item{row.clust}{boolean values determining if rows should be clustered}

\item{col.clust}{boolean values determining if cols should be clustered
and corresponding heatmap output, assuming clinical.mat is provided
the colors of the heatmap, otherwise min-max breaks are used by default}

\item{signif.stars.fl}{boolean determining whether significance stars of p-values are shown in the correlogram (default = FALSE)}

\item{cell.size}{double determining the width and height of the cell and the row/col font size (default = 8)}

\item{font.size}{double determining the font size (default = 10)}

\item{color.blind.pal}{string determining the RColorBrewer color blind palette (default = "PuOr");
other option can be visualized with the following command: brewer.pal.info[brewer.pal.info$colorblind,]}

\item{color.extremes}{character vector of length 2 giving the two extremes of a user-defined colour palette
varying from the first hue to the second via white.}

\item{anno.color}{list of named character vectors giving the colours used in the heatmap annotation bars. See 'annotation_colors'
in [pheatmap()]. Automatically generated if NULL (default).}

\item{main.correl}{Character; main title of the Correlogram}

\item{sample.correl}{Logical;}
}
\value{
Returns a pheatmap plot object used in the diffr_pheatmap() function.
}
\description{
Function to create a correlogram pheatmap, i.e., a plot to check randomness in the data set.
}
\details{
Calculates Pearson's rank correlation coefficients for all possible pairs of the input matrix and plots the resulting
correlation matrix, either with significance stars and coloured according to correlation or without stars and coloured
according to clinical annotation.
}
\author{
Bogdan Iancu - Genevia Technologies Oy
}
