% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diffwrap-package.R
\name{diffwrap}
\alias{diffwrap}
\title{Differential expression analysis of RNA-Seq data}
\description{
This package provides functionality for differential expression analysis of read counts from mRNA sequencing data or miRNA expression values
generated by the CAP-miRSEQ 'expression_reports.sh' script. The workflow follows the 'edgeR'-'limma' expression data analysis pipeline providing options
for different approaches, such as "pure" 'edgeR', 'voom' or paired samples. The functions in the package generate text files with differential expression lists,
optionally annotated with information from 'biomart', expression summary plots as well as several QC plots.
}
\details{
\tabular{ll}{
Package: \tab diffwrap\cr
Type: \tab Package\cr
Initial version: \tab 0.1-0\cr
Created: \tab 2015-08-27\cr
License: \tab GNU GPL v3 \cr
LazyLoad: \tab yes\cr
}
The package contains utilities and methods for differential expression analysis of RNA-Seq data.
It comes with a wrapper function, "diffExpr", performing all steps of the analysis. Most sub-functions are exported and can be called by the user, as well, if desired.
These functions may be applicable to different kinds of data/input, rely, however, on the conventions set for this package.
}
\section{Acknowledgements}{

This work was largely supported by university-level strategic and profiling area funding schemes at University of Turku
and Tampere University. Downstream analysis functionality including all pathway analyses and visualisations as well as some
DGE visualisations and helper functions were created or further developed at Genevia Technologies Oy.
}

\author{
Vidal Fey <vidal.fey@gmail.com>, Meeri Pekkarinen <meeri.pekkarinen@gmail.com>, Reija Hieta <reija.hieta@geneviatechnologies.com>, Bogdan Iancu <bogdan.iancu@abo.fi>, Adrien Janssens <Adrien.RFM.Janssens@proton.me>
Maintainer: Vidal Fey <vidal.fey@gmail.com>
}
\concept{RNA-seq}
\concept{differential gene expression}
\concept{edgeR}
\concept{limma}
\concept{linear modelling}
\concept{pathway analysis}
