% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qc_plots.R
\name{diff_expr_3d_scatterplot}
\alias{diff_expr_3d_scatterplot}
\title{Function to generate a 3D scatterplot}
\usage{
diff_expr_3d_scatterplot(
  PCA,
  samp.name = NULL,
  groups,
  grp.nam = NULL,
  PC = c(1, 2, 3),
  main = NULL
)
}
\arguments{
\item{PCA}{List of class \code{prcomp} or just a list having a component \code{x} that contains the rotated variables from \code{prcomp}.}

\item{samp.name}{Optional sample names to be used in the plot, given as character vector.}

\item{groups}{Sample groups for plot annotation as character vector or factor.}

\item{grp.nam}{Legend title.}

\item{PC}{Integer vector of length three specifying the principal components to be plotted.}

\item{main}{Plot title.}
}
\value{
No return value. Called for its side effect of drawing a three-dimensional PCA scatterplot on
  the current graphics device.
}
\description{
Function to generate a 3D scatterplot
}
\examples{
\donttest{
si <- diff_expr_get_samp_info(diffwrap_samp_info, "SampleName", "Group")
counts <- diff_expr_filter_counts(diff_expr_read_counts(diffwrap_counts, si), si)
groups <- stats::relevel(si$Groups, ref = "control")
pca <- diff_expr_PCA(edgeR::cpm(counts, log = TRUE), n = 100)
diff_expr_3d_scatterplot(pca, groups = groups)
}
}
