% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enrichment_util.R
\name{format_ensembl_ids_annotated_to_term}
\alias{format_ensembl_ids_annotated_to_term}
\title{Helper function for formatting the gene ID column of enrichment data frame.}
\usage{
format_ensembl_ids_annotated_to_term(result, species, which.split = ",")
}
\arguments{
\item{result}{Data.frame; a data frame with Ensembl Gene IDs in one (only one) column}

\item{species}{Character of length one; name of the species the IDs refer to. Only "human" and "mouse" are supported.}

\item{which.split}{Character; separator used in the ID column of \code{result}. See \emph{details}.}
}
\value{
The input enrichment result with the Ensembl gene identifiers in the gene column replaced by
  the corresponding gene symbols.
}
\description{
Helper function for formatting the gene ID column of enrichment data frame.
}
\details{
Enrichment tools report all genes annotated to a certain term in one string, separated by comma or similar. The function
  splits each row into individual IDs before converting and later re-collapses converted IDs.
}
